@@ -6,7 +6,7 @@
 #' @export
 BF.default <- function(x,
                        hypothesis = NULL,
-                       prior = NULL,
+                       prior.hyp = NULL,
                        complement = TRUE,
                        ...,
                        Sigma,
@@ -121,14 +121,14 @@ BF.default <- function(x,
     # the BF for the complement hypothesis vs Hu needs to be computed.
     BFtu_confirmatory <- c(apply(relfit / relcomp, 1, prod))
     # Check input of prior probabilies
-    if(is.null(prior)){
+    if(is.null(prior.hyp)){
       priorprobs <- rep(1/length(BFtu_confirmatory),length(BFtu_confirmatory))
     }else{
-      if(!is.numeric(prior) || length(prior)!=length(BFtu_confirmatory)){
-        warning(paste0("Argument 'prior' should be numeric and of length ",as.character(length(BFtu_confirmatory)),". Equal prior probabilities are used."))
+      if(!is.numeric(prior.hyp) || length(prior.hyp)!=length(BFtu_confirmatory)){
+        warning(paste0("Argument 'prior.hyp' should be numeric and of length ",as.character(length(BFtu_confirmatory)),". Equal prior probabilities are used."))
         priorprobs <- rep(1/length(BFtu_confirmatory),length(BFtu_confirmatory))
       }else{
-        priorprobs <- prior
+        priorprobs <- prior.hyp
       }
     }
     names(priorprobs) <- hypothesisshort
@@ -156,12 +156,12 @@ BF.default <- function(x,
     PHP_confirmatory=PHP_confirmatory,
     BFmatrix_confirmatory=BFmatrix_confirmatory,
     BFtable_confirmatory=BFtable,
-    prior=priorprobs,
+    prior.hyp=priorprobs,
     hypotheses=hypotheses,
     estimates=postestimates,
     model=x,
-    bayesfactor="Bayes factor using Gaussian approximations",
-    parameter="General",
+    bayesfactor="adjusted fractional Bayes factors using Gaussian approximations",
+    parameter="general parameters",
     call=match.call())
 
   class(BF_out) <- "BF"
